![](https://byob.yarr.is/simon-ritchie/apysc/time)

# apysc

apysc is a Python's frontend library to create html and js file, that has ActionScript 3 (as3)-like interface.

Notes: Currently developing and only works partially.

## Supported Python Version

Python 3.6 or later.

## Installing

```
$ pip install apysc
```
